"""This module is for the translation mapping data of the
following document:

Document file: easing_enum.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Easing enum": "# イージングのenum",
    ##################################################
    "This page explains the `Easing` enum class.": "このページでは`Easing`のenumのクラスについて説明します。",  # noqa
    ##################################################
    "## What class is this?": "## クラス概要",
    ##################################################
    "The `Easing` enum class defines each easing function. These are used at the animation interfaces, for example, the `animation_move` interface.": "`Easing`のenumのクラスは各イージング関数について定義しています。これらは`animation_move`などのアニメーションのインターフェイスで使用します。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "Each animation method interface, such as the `animation_move`\\, `animation_x`\\, has the `easing` argument. You can specify any of the `Easing` enums, as follows:": "`animation_move`や`animation_x`などの各アニメーションのメソッドのインターフェイスでは`easing`引数を持っており、以下のコード例のようにその引数に`Easing`のenumの値を指定することができます:",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\n\ndef on_animation_complete_1(e: ap.AnimationEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_move: ap.AnimationMove = e.this.target.animation_move(\n        x=50, y=50, duration=1000, easing=ap.Easing.EASE_OUT_QUINT\n    )\n    animation_move.animation_complete(on_animation_complete_2)\n    animation_move.start()\n\n\ndef on_animation_complete_2(e: ap.AnimationEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_move: ap.AnimationMove = e.this.target.animation_move(\n        x=100, y=100, duration=1000, easing=ap.Easing.EASE_OUT_QUINT\n    )\n    animation_move.animation_complete(on_animation_complete_1)\n    animation_move.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=200,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nanimation_move: ap.AnimationMove = rectangle.animation_move(\n    x=100, y=100, duration=1000, easing=ap.Easing.EASE_OUT_QUINT\n)\nanimation_move.animation_complete(on_animation_complete_1)\nanimation_move.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\n\ndef on_animation_complete_1(e: ap.AnimationEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_move: ap.AnimationMove = e.this.target.animation_move(\n        x=50, y=50, duration=1000, easing=ap.Easing.EASE_OUT_QUINT\n    )\n    animation_move.animation_complete(on_animation_complete_2)\n    animation_move.start()\n\n\ndef on_animation_complete_2(e: ap.AnimationEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_move: ap.AnimationMove = e.this.target.animation_move(\n        x=100, y=100, duration=1000, easing=ap.Easing.EASE_OUT_QUINT\n    )\n    animation_move.animation_complete(on_animation_complete_1)\n    animation_move.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=200,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nanimation_move: ap.AnimationMove = rectangle.animation_move(\n    x=100, y=100, duration=1000, easing=ap.Easing.EASE_OUT_QUINT\n)\nanimation_move.animation_complete(on_animation_complete_1)\nanimation_move.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_basic_usage/")\n```',  # noqa
    ##################################################
    "If you skip the specification of the `easing` argument, the animation becomes a linear one:": "もしも`easing`引数の指定を省略した場合、アニメーションは線形（スタートから終了まで一定の変動）のアニメーションとなります。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\n\ndef on_animation_complete_1(e: ap.AnimationEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_move: ap.AnimationMove = e.this.target.animation_move(\n        x=50, y=50, duration=1000\n    )\n    animation_move.animation_complete(on_animation_complete_2)\n    animation_move.start()\n\n\ndef on_animation_complete_2(e: ap.AnimationEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_move: ap.AnimationMove = e.this.target.animation_move(\n        x=100, y=100, duration=1000\n    )\n    animation_move.animation_complete(on_animation_complete_1)\n    animation_move.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=200,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nanimation_move: ap.AnimationMove = rectangle.animation_move(x=100, y=100, duration=1000)\nanimation_move.animation_complete(on_animation_complete_1)\nanimation_move.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_default_setting/")\n```': '```py\n# runnable\nimport apysc as ap\n\n\ndef on_animation_complete_1(e: ap.AnimationEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_move: ap.AnimationMove = e.this.target.animation_move(\n        x=50, y=50, duration=1000\n    )\n    animation_move.animation_complete(on_animation_complete_2)\n    animation_move.start()\n\n\ndef on_animation_complete_2(e: ap.AnimationEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_move: ap.AnimationMove = e.this.target.animation_move(\n        x=100, y=100, duration=1000\n    )\n    animation_move.animation_complete(on_animation_complete_1)\n    animation_move.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=200,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nanimation_move: ap.AnimationMove = rectangle.animation_move(x=100, y=100, duration=1000)\nanimation_move.animation_complete(on_animation_complete_1)\nanimation_move.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_default_setting/")\n```',  # noqa
    ##################################################
    "## What difference between the ease-in, ease-out, and ease-in-out": "## イーズイン（ease-in）、イーズアウト（ease-out）、イーズインアウト（ease-in-out）の違い",  # noqa
    ##################################################
    "- Ease-in starts with slow speed and stops with fast speed.": "- イーズイン（ease-in）は最初は遅くスタートし、最後の方で速いアニメーションになります。",  # noqa
    ##################################################
    "- Ease-out starts with fast speed and stops with slow speed.": "- イーズアウト（ease-out）は最初は速いスピードでスタートし、最後の方で遅いアニメーションになります。",  # noqa
    ##################################################
    "- Ease-in-out starts and stops with slow speed, and it gets faster on the way.": "- イーズインアウト（ease-in-out）は最初と最後の両方が遅いスピードとなり、中間で一番速いアニメーションとなります。",  # noqa
    ##################################################
    "The following example shows the difference between the `EASE_IN_QUINT`\\, `EASE_OUT_QUINT`\\, and `EASE_IN_OUT_QUINT`\\.": "以下のコード例では差が分かるように`EASE_IN_QUINT`、`EASE_OUT_QUINT`、`EASE_IN_OUT_QUINT`のそれぞれを表示しています。",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_QUINT\nEASING_2: ap.Easing = ap.Easing.EASE_OUT_QUINT\nEASING_3: ap.Easing = ap.Easing.EASE_IN_OUT_QUINT\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_difference/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_QUINT\nEASING_2: ap.Easing = ap.Easing.EASE_OUT_QUINT\nEASING_3: ap.Easing = ap.Easing.EASE_IN_OUT_QUINT\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_difference/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "## Ease-in examples": "## イーズインの例",
    ##################################################
    "This section shows each ease-in setting result with the x-coordinate animation.": "この節ではX座標のアニメーションにおける各イーズインの設定による例を表示しています。",  # noqa
    ##################################################
    "The following is the example of the `EASE_IN_SINE`, `EASE_IN_QUAD`, and `EASE_IN_CUBIC`:": "以下のコード例では`EASE_IN_SINE`、`EASE_IN_QUAD`、`EASE_IN_CUBIC`の各値を設定しています:",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_SINE\nEASING_2: ap.Easing = ap.Easing.EASE_IN_QUAD\nEASING_3: ap.Easing = ap.Easing.EASE_IN_CUBIC\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_1/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_SINE\nEASING_2: ap.Easing = ap.Easing.EASE_IN_QUAD\nEASING_3: ap.Easing = ap.Easing.EASE_IN_CUBIC\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_1/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "The following is the example of the `EASE_IN_QUART`, `EASE_IN_QUINT`, and `EASE_IN_EXPO`:": "以下のコード例では`EASE_IN_QUART`、`EASE_IN_QUINT`、`EASE_IN_EXPO`の各値を設定しています:",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_QUART\nEASING_2: ap.Easing = ap.Easing.EASE_IN_QUINT\nEASING_3: ap.Easing = ap.Easing.EASE_IN_EXPO\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_2/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_QUART\nEASING_2: ap.Easing = ap.Easing.EASE_IN_QUINT\nEASING_3: ap.Easing = ap.Easing.EASE_IN_EXPO\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_2/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "The following is the example of the `EASE_IN_CIRC` and `EASE_IN_BACK`:": "以下のコード例では`EASE_IN_CIRC`と`EASE_IN_BACK`の各値を設定しています:",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_CIRC\nEASING_2: ap.Easing = ap.Easing.EASE_IN_BACK\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_3/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_CIRC\nEASING_2: ap.Easing = ap.Easing.EASE_IN_BACK\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_3/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "The following is the example of the `EASE_IN_ELASTIC` and `EASE_IN_BOUNCE`:": "以下のコード例では`EASE_IN_ELASTIC`と`EASE_IN_BOUNCE`の各値を設定しています:",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_ELASTIC\nEASING_2: ap.Easing = ap.Easing.EASE_IN_BOUNCE\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_4/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_ELASTIC\nEASING_2: ap.Easing = ap.Easing.EASE_IN_BOUNCE\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_4/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "## Ease-out examples": "## イーズアウトの例",
    ##################################################
    "This section shows each ease-out result with the x-coordinate animation.": "この節ではX座標のアニメーションにおける各イーズアウトの設定による例を表示しています。",  # noqa
    ##################################################
    "The following is the example of the `EASE_OUT_SINE`, `EASE_OUT_QUAD`, and `EASE_OUT_CUBIC`:": "以下のコード例では`EASE_OUT_SINE`、`EASE_OUT_QUAD`、`EASE_OUT_CUBIC`の各値を設定しています:",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_OUT_SINE\nEASING_2: ap.Easing = ap.Easing.EASE_OUT_QUAD\nEASING_3: ap.Easing = ap.Easing.EASE_OUT_CUBIC\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_out_1/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_OUT_SINE\nEASING_2: ap.Easing = ap.Easing.EASE_OUT_QUAD\nEASING_3: ap.Easing = ap.Easing.EASE_OUT_CUBIC\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_out_1/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "The following is the example of the `EASE_OUT_QUART`, `EASE_OUT_QUINT`, and `EASE_OUT_EXPO`:": "以下のコード例では`EASE_OUT_QUART`, `EASE_OUT_QUINT`, `EASE_OUT_EXPO`の各値を設定しています:",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_OUT_QUART\nEASING_2: ap.Easing = ap.Easing.EASE_OUT_QUINT\nEASING_3: ap.Easing = ap.Easing.EASE_OUT_EXPO\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_out_2/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_OUT_QUART\nEASING_2: ap.Easing = ap.Easing.EASE_OUT_QUINT\nEASING_3: ap.Easing = ap.Easing.EASE_OUT_EXPO\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_out_2/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "The following is the example of the `EASE_OUT_CIRC` and `EASE_OUT_BACK`:": "以下のコード例では`EASE_OUT_CIRC`と`EASE_OUT_BACK`の各値を設定しています:",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_OUT_CIRC\nEASING_2: ap.Easing = ap.Easing.EASE_OUT_BACK\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_out_3/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_OUT_CIRC\nEASING_2: ap.Easing = ap.Easing.EASE_OUT_BACK\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_out_3/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "The following is the example of the `EASE_OUT_ELASTIC` and `EASE_OUT_BOUNCE`:": "以下のコード例では`EASE_OUT_ELASTIC`と`EASE_OUT_BOUNCE`の各値を設定しています。",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_OUT_ELASTIC\nEASING_2: ap.Easing = ap.Easing.EASE_OUT_BOUNCE\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_out_4/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_OUT_ELASTIC\nEASING_2: ap.Easing = ap.Easing.EASE_OUT_BOUNCE\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_out_4/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "## Ease-in-out examples": "## イーズインアウトの例",
    ##################################################
    "This section shows each ease-in-out setting result with the x-coordinate animation.": "この節ではX座標のアニメーションにおける各イーズインアウトの設定による例を表示しています。",  # noqa
    ##################################################
    "The following is the example of the `EASE_IN_OUT_SINE`, `EASE_IN_OUT_QUAD`, and `EASE_IN_OUT_CUBIC`:": "以下の例では`EASE_IN_OUT_SINE`, `EASE_IN_OUT_QUAD`, `EASE_IN_OUT_CUBIC`の各値を設定しています:",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_OUT_SINE\nEASING_2: ap.Easing = ap.Easing.EASE_IN_OUT_QUAD\nEASING_3: ap.Easing = ap.Easing.EASE_IN_OUT_CUBIC\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_out_1/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_OUT_SINE\nEASING_2: ap.Easing = ap.Easing.EASE_IN_OUT_QUAD\nEASING_3: ap.Easing = ap.Easing.EASE_IN_OUT_CUBIC\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_out_1/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "The following is the example of the `EASE_IN_OUT_QUART`, `EASE_IN_OUT_QUINT`, and `EASE_IN_OUT_EXPO`:": "以下のコード例では`EASE_IN_OUT_QUART`, `EASE_IN_OUT_QUINT`, `EASE_IN_OUT_EXPO`の各値を設定しています:",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_OUT_QUART\nEASING_2: ap.Easing = ap.Easing.EASE_IN_OUT_QUINT\nEASING_3: ap.Easing = ap.Easing.EASE_IN_OUT_EXPO\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_out_2/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_OUT_QUART\nEASING_2: ap.Easing = ap.Easing.EASE_IN_OUT_QUINT\nEASING_3: ap.Easing = ap.Easing.EASE_IN_OUT_EXPO\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=350,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_3.animation_x(x=x, duration=DURATION, easing=EASING_3)\noptions = {"easing": EASING_3}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_out_2/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "The following is the example of the `EASE_IN_OUT_CIRC` and `EASE_IN_OUT_BACK`:": "以下のコード例では`EASE_IN_OUT_CIRC`と`EASE_IN_OUT_BACK`の各値を設定しています:",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_OUT_CIRC\nEASING_2: ap.Easing = ap.Easing.EASE_IN_OUT_BACK\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_out_3/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_OUT_CIRC\nEASING_2: ap.Easing = ap.Easing.EASE_IN_OUT_BACK\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_out_3/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
    ##################################################
    "The following is the example of the `EASE_IN_OUT_ELASTIC` and `EASE_IN_OUT_BOUNCE`:": "以下のコード例では`EASE_IN_OUT_ELASTIC`と`EASE_IN_OUT_BOUNCE`の各値を設定しています:",  # noqa
    ##################################################
    "<details>\n<summary>Display the code block:</summary>": "<details>\n<summary>コードブロックを表示:</summary>",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_OUT_ELASTIC\nEASING_2: ap.Easing = ap.Easing.EASE_IN_OUT_BOUNCE\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_out_4/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _EasingOptions(TypedDict):\n    easing: ap.Easing\n\n\nDURATION: int = 1000\nEASING_1: ap.Easing = ap.Easing.EASE_IN_OUT_ELASTIC\nEASING_2: ap.Easing = ap.Easing.EASE_IN_OUT_BOUNCE\n\n\ndef on_animation_complete_1(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=50, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_2, options=options)\n    animation_x.start()\n\n\ndef on_animation_complete_2(\n    e: ap.AnimationEvent[ap.Rectangle], options: _EasingOptions\n) -> None:\n    """\n    The handler that the animation calls when its end.\n\n    Parameters\n    ----------\n    e : ap.AnimationEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    animation_x: ap.AnimationX = e.this.target.animation_x(\n        x=100, duration=DURATION, easing=options["easing"]\n    )\n    animation_x.animation_complete(on_animation_complete_1, options=options)\n    animation_x.start()\n\n\nap.Stage(\n    stage_width=200,\n    stage_height=250,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=150, width=50, height=50)\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=250, width=50, height=50)\n\nx: int = 100\nanimation_x: ap.AnimationX = rectangle_1.animation_x(\n    x=x, duration=DURATION, easing=EASING_1\n)\noptions: _EasingOptions = {"easing": EASING_1}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nanimation_x = rectangle_2.animation_x(x=x, duration=DURATION, easing=EASING_2)\noptions = {"easing": EASING_2}\nanimation_x.animation_complete(on_animation_complete_1, options=options)\nanimation_x.start()\n\nap.save_overall_html(dest_dir_path="./easing_enum_ease_in_out_4/")\n```',  # noqa
    ##################################################
    "</details>": "</details>",
}



"""This module is for the translation mapping data of the
following document:

Document file: true_and_false.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# True_ and False_ constants": "# True_ と False_ の各定数",
    ##################################################
    "This page explains the `ap.True_` and `ap.False_` constants.": "このページでは`ap.True_`と`ap.False_`の各定数について説明します。",  # noqa
    ##################################################
    "## What constants are these?": "## 各定数の概要",
    ##################################################
    "The `ap.True_` is the constant that indicates `Boolean`'s `True` value (it is almost the same as `ap.Boolean(True)`).": "`ap.True_`は`Boolean`の`True`の値を示すたの定数値です（これは`ap.Boolean(True)`とほぼ同じ値となります）。",  # noqa
    ##################################################
    "Conversely, the `ap.False_` is the constant that indicates `Boolean`'s `False` value.": "反対に、`ap.False_`は`Boolean`の`False`の値を示すための定数となります。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `True_` and `False_` constants behave like `ap.Boolean(True)` and `ap.Boolean(False)`.": "`True_`と`False_`の各定数は`ap.Boolean(True)`や`ap.Boolean(False)`などと同じように振る舞います。",  # noqa
    ##################################################
    "A function or method that takes a `Boolean` argument can accept these constants.": "`Boolean`の引数を取る関数やメソッドなどではこれらの定数を指定することができます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=100,\n    stage_height=50,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\ntext: ap.SvgText = ap.SvgText(\n    text="Hello!",\n    x=10,\n    y=31,\n    fill_color=ap.Color("#aaa"),\n    bold=ap.True_,\n    italic=ap.False_,\n)\n\nap.save_overall_html(dest_dir_path="true_and_false_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=100,\n    stage_height=50,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\ntext: ap.SvgText = ap.SvgText(\n    text="Hello!",\n    x=10,\n    y=31,\n    fill_color=ap.Color("#aaa"),\n    bold=ap.True_,\n    italic=ap.False_,\n)\n\nap.save_overall_html(dest_dir_path="true_and_false_basic_usage/")\n```',  # noqa
}



"""The class implementation for the outlined `star_rate` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialStarRateOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `star_rate` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24" x="0"/><path d="M12,8.89L12.94,12h2.82l-2.27,1.62l0.93,3.01L12,14.79l-2.42,1.84l0.93-3.01L8.24,12h2.82L12,8.89 M12,2l-2.42,8H2 l6.17,4.41L5.83,22L12,17.31L18.18,22l-2.35-7.59L22,10h-7.58L12,2L12,2z"/></g></svg>'  # noqa



"""The mix-in class for the `foreignObject`'s width initialization method.
"""

from typing import Union

from typing_extensions import final

from apysc._html.debug_mode import add_debug_info_setting
from apysc._type.int import Int


class SvgForeignObjectInitializeWidthMixIn:
    _width: Int

    @final
    @add_debug_info_setting(module_name=__name__)
    def _initialize_width(
        self,
        *,
        width: Union[int, Int],
    ) -> None:
        """
        Initialize the width attribute with the specified argument.

        Parameters
        ----------
        width : Union[int, Int]
            Element width value.
        """
        from apysc._converter import to_apysc_val_from_builtin
        from apysc._type.variable_name_suffix_attr_or_var_mixin import (
            VariableNameSuffixAttrOrVarMixIn,
        )

        suffix: str = ""
        if isinstance(self, VariableNameSuffixAttrOrVarMixIn):
            suffix = self._get_attr_or_variable_name_suffix(value_identifier="width")
        width_: Int = to_apysc_val_from_builtin.get_copied_int_from_builtin_val(
            integer=width,
            variable_name_suffix=suffix,
        )
        self._width = width_



"""The class implementation for the `commute` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialCommuteIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `commute` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0z" fill="none"/><path d="M12 4H5C3.34 4 2 5.34 2 7v8c0 1.66 1.34 3 3 3l-1 1v1h1l2-2.03L9 18v-5H4V5.98L13 6v2h2V7c0-1.66-1.34-3-3-3zM5 14c.55 0 1 .45 1 1s-.45 1-1 1-1-.45-1-1 .45-1 1-1zm15.57-4.34c-.14-.4-.52-.66-.97-.66h-7.19c-.46 0-.83.26-.98.66L10 13.77l.01 5.51c0 .38.31.72.69.72h.62c.38 0 .68-.38.68-.76V18h8v1.24c0 .38.31.76.69.76h.61c.38 0 .69-.34.69-.72l.01-1.37v-4.14l-1.43-4.11zm-8.16.34h7.19l1.03 3h-9.25l1.03-3zM12 16c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1zm8 0c-.55 0-1-.45-1-1s.45-1 1-1 1 .45 1 1-.45 1-1 1z"/></svg>'  # noqa



"""This module is for the E2E testing common utilities
and definitions.
"""

import os
from logging import Logger
from typing import Callable
from typing import List
from typing import Optional as Op

from playwright.sync_api import Browser
from playwright.sync_api import ConsoleMessage
from playwright.sync_api import Error
from playwright.sync_api import Page
from playwright.sync_api import sync_playwright
from typing_extensions import TypedDict

from apysc._console import loggers
from apysc._lint_and_doc.docs_lang import Lang

LOCAL_FILE_PATH_PREFIX: str = f'file://{os.path.abspath("./")}/'
logger: Logger = loggers.get_info_logger()


def get_docs_local_file_path(*, lang: Lang, file_name: str) -> str:
    """
    Get a document's local file path for the E2E testing.

    Parameters
    ----------
    lang : Lang
        A target language.
    file_name : str
        A target file name (e.g., `index`).

    Returns
    -------
    file_path : str
        A target document's local file path.
    """
    file_path: str = os.path.join(
        LOCAL_FILE_PATH_PREFIX,
        f"docs/{lang.value}/{file_name}.html",
    )
    return file_path


def _assert_local_file_error_log_not_exits(*, file_path: str) -> None:
    """
    Assert that local file assertion's an error log does not exist.

    Parameters
    ----------
    file_path : str
        A target file path.

    Raises
    ------
    AssertionError
        If there is an error log file.
    """
    from apysc._file import file_util

    local_file_page_err_file_path: str = _get_local_file_page_err_file_path(
        file_path=file_path
    )
    local_file_assertion_err_file_path: str = _get_local_file_assertion_err_file_path(
        file_path=file_path
    )
    log_file_paths: List[str] = [
        local_file_page_err_file_path,
        local_file_assertion_err_file_path,
    ]
    for log_file_path in log_file_paths:
        if not os.path.isfile(log_file_path):
            continue
        log_txt: str = file_util.read_txt(file_path=log_file_path)
        raise AssertionError(log_txt)


def _delete_local_file_assertion_error_logs(*, file_path: str) -> None:
    """
    Delete local files assertion error logs files if they exist.

    Parameters
    ----------
    file_path : str
        A target local file path.
    """
    from apysc._file import file_util

    local_file_page_err_file_path: str = _get_local_file_page_err_file_path(
        file_path=file_path
    )
    file_util.delete_file_if_exists(file_path=local_file_page_err_file_path)

    local_file_assertion_err_file_path: str = _get_local_file_assertion_err_file_path(
        file_path=file_path
    )
    file_util.delete_file_if_exists(file_path=local_file_assertion_err_file_path)


_FILE_PATH_SUFFIX_LOCAL_FILE_PAGE_ERR: str = "e2e_testing_local_file_page_error_"
_FILE_PATH_SUFFIX_LOCAL_FILE_ASSERT_ERR: str = "e2e_testing_local_file_assertion_error_"


def _get_local_file_assertion_err_file_path(*, file_path: str) -> str:
    """
    Get an assertion error log's file path of a local file.

    Parameters
    ----------
    file_path : str
        A target local file path.

    Returns
    -------
    log_file_path : str
        An assertion error log's file path of a local file.
    """
    file_path = _replace_paths_symbols_by_underscore(file_path=file_path)
    os.makedirs("./tmp/", exist_ok=True)
    log_file_path: str = (
        f"./tmp/{_FILE_PATH_SUFFIX_LOCAL_FILE_ASSERT_ERR}{file_path}.log"
    )
    return log_file_path


def _get_local_file_page_err_file_path(*, file_path: str) -> str:
    """
    Get a page error log's file path of a local file.

    Parameters
    ----------
    file_path : str
        A target local file path.

    Returns
    -------
    log_file_path : str
        A page error's log file path of a local file.
    """
    file_path = _replace_paths_symbols_by_underscore(file_path=file_path)
    os.makedirs("./tmp/", exist_ok=True)
    log_file_path: str = f"./tmp/{_FILE_PATH_SUFFIX_LOCAL_FILE_PAGE_ERR}{file_path}.log"
    return log_file_path


def _replace_paths_symbols_by_underscore(*, file_path: str) -> str:
    """
    Replace the path's symbols with the underscore symbol.

    Parameters
    ----------
    file_path : str
        A target file path.

    Returns
    -------
    file_path : str
        A result file path.
    """
    symbols: List[str] = [":", "/", "."]
    for symbol in symbols:
        file_path = file_path.replace(symbol, "_")
    return file_path


def _get_local_file_page_err_handler(*, file_path: str) -> Callable[[Error], None]:
    """
    Get a page error's event handler.

    Parameters
    ----------
    file_path : str
        A target local file path.

    Returns
    -------
    handler : Callable
        A target handler.
    """
    from apysc._file import file_util

    def handler(err: Error) -> None:
        """
        A handler of this event.

        Parameters
        ----------
        err : Error
            _description_
        """
        log_file_path: str = _get_local_file_page_err_file_path(file_path=file_path)

        file_path_: str = file_path.replace("file://", "", 1)
        file_txt: str = ""
        if os.path.isfile(file_path_):
            file_txt = file_util.read_txt(file_path=file_path_)
        err_msg: str = (
            "There is an unexpected error in the following "
            f"Local file: {file_path}"
            f"\nError message: {err.message}"
            f"\nStack trace: {err.stack}"
            f"\nLocal file text:\n\n{file_txt}"
        )
        file_util.save_plain_txt(txt=err_msg, file_path=log_file_path)
        raise AssertionError(err_msg)

    return handler


_ConsoleHandler = Callable[[ConsoleMessage], None]


def _get_local_file_console_event_handler(
    *, file_path: str, expected_assert_f_msgs: Op[List[str]] = None
) -> _ConsoleHandler:
    """
    Get a console event's handler.

    Parameters
    ----------
    file_path : str
        A target local file path.
    expected_assert_f_msgs : list of str or None, default None
        Expected assertion failed messages.

    Returns
    -------
    handler : Callable
        A target handler.
    """
    from apysc._file import file_util

    def handler(message: ConsoleMessage) -> None:
        """
        A handler of this event.

        Parameters
        ----------
        message : ConsoleMessage
            A target console message instance.
        """
        if message.type != "assert":
            return
        if (
            expected_assert_f_msgs is not None
            and message.text in expected_assert_f_msgs
        ):
            return
        log_file_path: str = _get_local_file_assertion_err_file_path(
            file_path=file_path
        )
        err_msg: str = (
            "There is an unexpected assertion error in the "
            f"following local file: {file_path}"
            f"\nError message: {message.text}"
        )
        file_util.save_plain_txt(txt=err_msg, file_path=log_file_path)
        raise AssertionError(err_msg)

    return handler


class LocalFileData(TypedDict):
    file_path: str
    expected_assertion_failed_msgs: Op[List[str]]


def assert_local_files_not_raise_error(
    *, local_file_data_list: List[LocalFileData]
) -> None:
    """
    Assert specified local files do not raise an error.

    Parameters
    ----------
    local_file_data_list : List[LocalFileData]
        A target local file data list.

    Raises
    ------
    AssertionError
        If specified files raise an exception.
    """
    with sync_playwright() as p:
        browser: Browser = p.chromium.launch()
        for local_file_data in local_file_data_list:
            file_path: str = local_file_data["file_path"]
            _delete_local_file_assertion_error_logs(file_path=file_path)
            expected_assert_f_msgs: Op[List[str]] = local_file_data[
                "expected_assertion_failed_msgs"
            ]
            logger.info(f"Local file's assertion started: {file_path}")
            for _ in range(2):
                page: Page = browser.new_page()
                page.on(
                    event="console",
                    f=_get_local_file_console_event_handler(
                        file_path=file_path,
                        expected_assert_f_msgs=expected_assert_f_msgs,
                    ),
                )
                page.on(
                    event="pageerror",
                    f=_get_local_file_page_err_handler(file_path=file_path),
                )
                page.goto(url=file_path)
                _assert_local_file_error_log_not_exits(file_path=file_path)



"""The class implementation for the outlined `screen_share` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialScreenShareOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `screen_share` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M20 18c1.1 0 1.99-.9 1.99-2L22 6c0-1.11-.9-2-2-2H4c-1.11 0-2 .89-2 2v10c0 1.1.89 2 2 2H0v2h24v-2h-4zM4 16V6h16v10.01L4 16zm9-6.87c-3.89.54-5.44 3.2-6 5.87 1.39-1.87 3.22-2.72 6-2.72v2.19l4-3.74L13 7v2.13z"/></svg>'  # noqa



"""The mix-in class implementation for the `to_number` method.
"""

from typing import TYPE_CHECKING

from typing_extensions import final

from apysc._html.debug_mode import add_debug_info_setting

if TYPE_CHECKING:
    from apysc._type.number import Number


class ToNumberMixIn:
    @final
    @add_debug_info_setting(module_name=__name__)
    def to_number(self, *, variable_name_suffix: str = "") -> "Number":
        """
        Convert this value to an `ap.Number` value.

        Parameters
        ----------
        variable_name_suffix : str, optional
            A JavaScript variable name suffix string.
            This setting is sometimes useful for JavaScript debugging.

        Returns
        -------
        number : Number
            A converted number.
        """
        from apysc._expression import expression_data_util
        from apysc._type.boolean import Boolean
        from apysc._type.int import Int
        from apysc._type.number import Number
        from apysc._type.string import String
        from apysc._validation.variable_name_validation import (
            validate_variable_name_mixin_type,
        )

        self_variable_name: str = validate_variable_name_mixin_type(
            instance=self
        ).variable_name
        number: Number = Number(0.0, variable_name_suffix=variable_name_suffix)
        py_value: float = 0
        if isinstance(self, (Int, String, Boolean)):
            py_value = float(self._value)
        number._value = py_value
        expression: str = f"{number.variable_name} = Number({self_variable_name});"
        expression_data_util.append_js_expression(expression=expression)

        return number



"""Elif (else if) branch instruction implementations.
"""

from typing import Any
from typing import Dict
from typing import Optional

from typing_extensions import final

from apysc._branch.if_base import IfBase
from apysc._html.debug_mode import add_debug_info_setting
from apysc._type.boolean import Boolean
from apysc._validation import arg_validation_decos


class Elif(IfBase):
    """
    A class to append the `else if` branch instruction expression.

    References
    ----------
    - Elif
        - https://simon-ritchie.github.io/apysc/en/elif.html
    - Each branch instruction class's scope variables reverting setting
        - https://simon-ritchie.github.io/apysc/en/branch_instruction_variables_reverting_setting.html  # noqa

    Notes
    -----
    - Currently the apysc can not initialize condition value
        in the constructor. For example, the following raises
        an exception:
    - You can only use this class immediately after the
        `If` or `Elif` statement.

    Examples
    --------
    >>> import apysc as ap
    >>> any_value: ap.Int = ap.Int(10)
    >>> condition_1: ap.Boolean = any_value >= 10
    >>> condition_2: ap.Boolean = any_value >= 5
    >>> with ap.If(condition_1):
    ...     # Do something here
    ...     pass
    ...
    >>> with ap.Elif(condition_2):
    ...     # Do something else here
    ...     pass
    ...
    """

    @final
    @arg_validation_decos.is_apysc_boolean(arg_position_index=1)
    @arg_validation_decos.is_vars_dict(arg_position_index=2)
    @arg_validation_decos.is_vars_dict(arg_position_index=3)
    @add_debug_info_setting(module_name=__name__)
    def __init__(
        self,
        condition: Optional[Boolean],
        *,
        locals_: Optional[Dict[str, Any]] = None,
        globals_: Optional[Dict[str, Any]] = None,
    ) -> None:
        """
        A class to append the `else if` branch instruction expression.

        Notes
        -----
        - Currently the apysc can not initialize condition value
            in the constructor.
        - You can only use this class immediately after the
            `If` or `Elif` statement.

        Examples
        --------
        >>> # You can avoid notes exception by predefining condition
        >>> # value, as follows:
        >>> import apysc as ap
        >>> any_value: ap.Int = ap.Int(10)
        >>> condition_1: ap.Boolean = any_value >= 10
        >>> condition_2: ap.Boolean = any_value >= 5
        >>> with ap.If(condition_1):
        ...     # Do something here
        ...     pass
        ...
        >>> with ap.Elif(condition_2):
        ...     # Do something else here
        ...     pass
        ...

        Parameters
        ----------
        condition : Boolean or None
            Boolean value to be used for judgment.
        locals_ : dict or None, default None
            Current scope's local variables. Set locals()
            value to this argument. If specified, this interface
            reverts all local scope VariableNameMixIn
            variables (like Int, Sprite) at the end of an `Elif`
            scope. This setting is useful when you don't want to
            update each variable by implementing the `Elif` scope.
        globals_ : dict or None, default None
            Current scope's global variables. Set globals()
            value to this argument. This setting works
            the same way as the locals_ argument.

        References
        ----------
        - Elif
            - https://simon-ritchie.github.io/apysc/en/elif.html
        - Each branch instruction class's scope variables reverting setting
            - https://simon-ritchie.github.io/apysc/en/branch_instruction_variables_reverting_setting.html  # noqa
        """
        super(Elif, self).__init__(
            condition=condition, locals_=locals_, globals_=globals_
        )

    @final
    def _append_enter_expression(self) -> None:
        """
        Append else if branch instruction starting expression.

        Raises
        ------
        ValueError
            If the last scope is not If or Elif.
        """
        from apysc._expression import expression_data_util

        if not self._last_scope_is_if_or_elif():
            raise ValueError(
                "Elif interface can only use right after If or Elif "
                "interfaces."
                "\n\nMaybe you are using Int or String, or anything else"
                " comparison expression at Elif constructor (e.g., "
                "`with Elif(any_value == 10, ...):`)."
                "\nCurrently that specifying expression directly is not "
                "supported so please"
                " define condition seperately as follows:"
                "\ncondition: Boolean = any_value == 10"
                "\n..."
                "\nwith Elif(condition, ....):"
            )
        if self._condition is None:
            raise ValueError("Elif expression's condition argument can't be set None.")
        expression: str = f"else if ({self._condition.variable_name}) {{"
        expression_data_util.append_js_expression(expression=expression)

    @final
    def _set_last_scope(self) -> None:
        """
        Set expression last scope value.
        """
        from apysc._expression import last_scope
        from apysc._expression.last_scope import LastScope

        last_scope.set_last_scope(value=LastScope.ELIF)



"""The class implementation for the outlined `alarm_add` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialAlarmAddOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `alarm_add` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M17.337 1.81l4.607 3.845-1.28 1.535-4.61-3.843zm-10.674 0l1.282 1.536L3.337 7.19l-1.28-1.536zM12 4c-4.97 0-9 4.03-9 9s4.03 9 9 9 9-4.03 9-9-4.03-9-9-9zm0 16c-3.86 0-7-3.14-7-7s3.14-7 7-7 7 3.14 7 7-3.14 7-7 7zm1-11h-2v3H8v2h3v3h2v-3h3v-2h-3z"/></svg>'  # noqa



"""The class implementation for the `eco` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialEcoIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `eco` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><path d="M6.05,8.05c-2.73,2.73-2.73,7.15-0.02,9.88c1.47-3.4,4.09-6.24,7.36-7.93c-2.77,2.34-4.71,5.61-5.39,9.32 c2.6,1.23,5.8,0.78,7.95-1.37C19.43,14.47,20,4,20,4S9.53,4.57,6.05,8.05z"/></g></g></svg>'  # noqa



"""The class implementation for the outlined `lightbulb` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialLightbulbOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `lightbulb` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0z" fill="none"/><path d="M9 21c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-1H9v1zm3-19C8.14 2 5 5.14 5 9c0 2.38 1.19 4.47 3 5.74V17c0 .55.45 1 1 1h6c.55 0 1-.45 1-1v-2.26c1.81-1.27 3-3.36 3-5.74 0-3.86-3.14-7-7-7zm2.85 11.1l-.85.6V16h-4v-2.3l-.85-.6C7.8 12.16 7 10.63 7 9c0-2.76 2.24-5 5-5s5 2.24 5 5c0 1.63-.8 3.16-2.15 4.1z"/></svg>'  # noqa



"""The class implementation for the outlined `backup` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialBackupOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `backup` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M19.35 10.04C18.67 6.59 15.64 4 12 4 9.11 4 6.6 5.64 5.35 8.04 2.34 8.36 0 10.91 0 14c0 3.31 2.69 6 6 6h13c2.76 0 5-2.24 5-5 0-2.64-2.05-4.78-4.65-4.96zM19 18H6c-2.21 0-4-1.79-4-4 0-2.05 1.53-3.76 3.56-3.97l1.07-.11.5-.95C8.08 7.14 9.94 6 12 6c2.62 0 4.88 1.86 5.39 4.43l.3 1.5 1.53.11c1.56.1 2.78 1.41 2.78 2.96 0 1.65-1.35 3-3 3zM8 13h2.55v3h2.9v-3H16l-4-4z"/></svg>'  # noqa



"""The mix-in class implementation for the `SvgText`'s `_set_font_size_value` method.
"""

from typing import Optional
from typing import Union

from typing_extensions import final

from apysc._html.debug_mode import add_debug_info_setting
from apysc._type.int import Int


class SvgTextSetFontSizeValueMixIn:
    @final
    @add_debug_info_setting(module_name=__name__)
    def _set_font_size_value(self, *, font_size: Optional[Union[int, Int]]) -> None:
        """
        Set a font-size value.

        Parameters
        ----------
        font_size : Optional[Union[int, Int]]
            A target font-size value. If this value is None,
            this method does not set a font-size value.
        """
        from apysc._display.svg_text_font_size_mixin import SvgTextFontSizeMixIn
        from apysc._type.variable_name_suffix_utils import (
            get_attr_or_variable_name_suffix,
        )

        if font_size is None:
            return
        if not isinstance(self, SvgTextFontSizeMixIn):
            raise TypeError(
                f"This method is only supported an {SvgTextFontSizeMixIn.__name__} "
                f"instance: {type(self).__name__}"
            )

        if isinstance(font_size, int):
            suffix: str = get_attr_or_variable_name_suffix(
                instance=self, value_identifier="font_size"
            )
            font_size_: Int = Int(font_size, variable_name_suffix=suffix)
        else:
            font_size_ = font_size
        self.font_size = font_size_



"""The class implementation for the outlined `donut_large` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialDonutLargeOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `donut_large` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M13 5.08c3.06.44 5.48 2.86 5.92 5.92h3.03c-.47-4.72-4.23-8.48-8.95-8.95v3.03zM18.92 13c-.44 3.06-2.86 5.48-5.92 5.92v3.03c4.72-.47 8.48-4.23 8.95-8.95h-3.03zM11 18.92c-3.39-.49-6-3.4-6-6.92s2.61-6.43 6-6.92V2.05c-5.05.5-9 4.76-9 9.95 0 5.19 3.95 9.45 9 9.95v-3.03z"/></svg>'  # noqa



"""The class implementation for the outlined `restore_page` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialRestorePageOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `restore_page` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M14 2H6c-1.1 0-1.99.9-1.99 2L4 20c0 1.1.89 2 1.99 2H18c1.1 0 2-.9 2-2V8l-6-6zm4 18H6V4h7.17L18 8.83V20zm-9.55-9.43L7.28 9.4V13h3.6l-1.44-1.44c.52-1.01 1.58-1.71 2.79-1.71 1.74 0 3.15 1.41 3.15 3.15s-1.41 3.15-3.15 3.15c-1.07 0-2.02-.54-2.58-1.35H8.1c.69 1.58 2.28 2.7 4.12 2.7 2.48 0 4.5-2.02 4.5-4.5s-2.02-4.5-4.5-4.5c-1.59 0-2.97.83-3.77 2.07z"/></svg>'  # noqa



"""The class implementation for the outlined `favorite` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialFavoriteOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `favorite` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M12 21.35l-1.45-1.32C5.4 15.36 2 12.28 2 8.5 2 5.42 4.42 3 7.5 3c1.74 0 3.41.81 4.5 2.09C13.09 3.81 14.76 3 16.5 3 19.58 3 22 5.42 22 8.5c0 3.78-3.4 6.86-8.55 11.54L12 21.35z"/></svg>'  # noqa



"""The mix-in class implementation for the `tick_text_italic` value.
"""

from typing import Union

from typing_extensions import final

from apysc._html.debug_mode import add_debug_info_setting
from apysc._type.boolean import Boolean
from apysc._validation import arg_validation_decos


class TickTextItalicMixIn:
    _tick_text_italic: Boolean

    @final
    @arg_validation_decos.is_boolean(arg_position_index=1, optional=False)
    @add_debug_info_setting(module_name=__name__)
    def _set_initial_tick_text_italic(
        self,
        *,
        tick_text_italic: Union[bool, Boolean],
        variable_name_suffix: str = "",
    ) -> None:
        """
        Set an initial boolean value, whether a tick text is
        an italic style or not (normal).

        Parameters
        ----------
        tick_text_italic : Union[bool, Boolean]
            A boolean, whether a tick text is an italic style or not (normal).
        variable_name_suffix : str, optional
            A JavaScript variable name suffix string.
            This setting is sometimes useful for JavaScript debugging.
        """
        if not isinstance(tick_text_italic, Boolean):
            tick_text_italic_: Boolean = Boolean(
                tick_text_italic,
                variable_name_suffix=variable_name_suffix,
            )
        else:
            tick_text_italic_ = tick_text_italic
        self._tick_text_italic = tick_text_italic_



"""The class implementation for the `fiber_pin` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialFiberPinIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `fiber_pin` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0z" fill="none"/><path d="M5.5 10.5h2v1h-2zM20 4H4c-1.11 0-1.99.89-1.99 2L2 18c0 1.11.89 2 2 2h16c1.11 0 2-.89 2-2V6c0-1.11-.89-2-2-2zM9 11.5c0 .85-.65 1.5-1.5 1.5h-2v2H4V9h3.5c.85 0 1.5.65 1.5 1.5v1zm3.5 3.5H11V9h1.5v6zm7.5 0h-1.2l-2.55-3.5V15H15V9h1.25l2.5 3.5V9H20v6z"/></svg>'  # noqa



"""The class implementation for the `all_out` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialAllOutIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `all_out` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M16.21 4.16l4 4v-4zm4 12l-4 4h4zm-12 4l-4-4v4zm-4-12l4-4h-4zm12.95-.95c-2.73-2.73-7.17-2.73-9.9 0s-2.73 7.17 0 9.9 7.17 2.73 9.9 0 2.73-7.16 0-9.9zm-1.1 8.8c-2.13 2.13-5.57 2.13-7.7 0s-2.13-5.57 0-7.7 5.57-2.13 7.7 0 2.13 5.57 0 7.7z"/><path d="M.21.16h24v24h-24z" fill="none"/></svg>'  # noqa



"""This module is for the translation mapping data of the
following document:

Document file: color_from_rgb.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Color class from_rgb class method": "# Color クラスの from_rgb クラスメソッド",
    ##################################################
    "This pace explains the `Color` class `from_rgb` class method.": "このページでは`Color`クラスの`from_rgb`クラスメソッドについて説明します。",  # noqa
    ##################################################
    "## What class method is this?": "## クラスメソッド概要",
    ##################################################
    "The `from_rgb` class method creates a new color instance from red, green and blue integer (0 to 255, 8bit unsigned integer range).": "`from_rgs`クラスメソッドは赤緑青の3色の指定から新たな色のインスタンスを作成します（0～255の8bitの正の整数の範囲を受け付けます）。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `from_rgb` class method requires the `red`, `green`, and `blue` arguments (`int` or `ap.Int` type value).": "`from_rgb`クラスメソッドは`red`、`green`、`blue`の各引数を必要とします（`int`もしくは`ap.Int`型の値）。",  # noqa
    ##################################################
    "Its class method returns a new color instance.": "このクラスメソッドは新たな色のインスタンスを返します。",
    ##################################################
    '```py\n# runnable\n\nimport apysc as ap\n\nap.Stage(\n    stage_width=350,\n    stage_height=150,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\n\nblack_color: ap.Color = ap.Color.from_rgb(red=0, green=0, blue=0)\nblack_rectangle: ap.Rectangle = ap.Rectangle(\n    x=50,\n    y=50,\n    width=50,\n    height=50,\n    fill_color=black_color,\n)\n\nwhite_color: ap.Color = ap.Color.from_rgb(red=255, green=255, blue=255)\nwhite_rectangle: ap.Rectangle = ap.Rectangle(\n    x=150,\n    y=50,\n    width=50,\n    height=50,\n    fill_color=white_color,\n)\n\ncyan_color: ap.Color = ap.Color.from_rgb(red=0, green=128, blue=255)\ncyan_rectangle: ap.Rectangle = ap.Rectangle(\n    x=250,\n    y=50,\n    width=50,\n    height=50,\n    fill_color=cyan_color,\n)\n\nap.save_overall_html(dest_dir_path="color_from_rgb_basic_usage/")\n```': '```py\n# runnable\n\nimport apysc as ap\n\nap.Stage(\n    stage_width=350,\n    stage_height=150,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\n\nblack_color: ap.Color = ap.Color.from_rgb(red=0, green=0, blue=0)\nblack_rectangle: ap.Rectangle = ap.Rectangle(\n    x=50,\n    y=50,\n    width=50,\n    height=50,\n    fill_color=black_color,\n)\n\nwhite_color: ap.Color = ap.Color.from_rgb(red=255, green=255, blue=255)\nwhite_rectangle: ap.Rectangle = ap.Rectangle(\n    x=150,\n    y=50,\n    width=50,\n    height=50,\n    fill_color=white_color,\n)\n\ncyan_color: ap.Color = ap.Color.from_rgb(red=0, green=128, blue=255)\ncyan_rectangle: ap.Rectangle = ap.Rectangle(\n    x=250,\n    y=50,\n    width=50,\n    height=50,\n    fill_color=cyan_color,\n)\n\nap.save_overall_html(dest_dir_path="color_from_rgb_basic_usage/")\n```',  # noqa
    ##################################################
    "## from_rgb class method API": "## from_rgb クラスメソッドのAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Create a color instance from RGB (red, green, and blue) values.<hr>": "RGB（赤、緑、青）の値から色のインスタンスを生成します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `red`: Union[int, Int]": "- `red`: Union[int, Int]",
    ##################################################
    "  - A red color value (0 to 255).": "  - 赤色の値（0～255）。",
    ##################################################
    "- `green`: Union[int, Int]": "- `green`: Union[int, Int]",
    ##################################################
    "  - A green color value (0 to 255).": "  - 緑色の値（0～255）。",
    ##################################################
    "- `blue`: Union[int, Int]": "- `blue`: Union[int, Int]",
    ##################################################
    "  - A blue color value (0 to 255).": "  - 青色の値（0～255）。",
    ##################################################
    '- `variable_name_suffix`: str, default ""': '- `variable_name_suffix`: str, default ""',  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `color`: Color": "- `color`: Color",
    ##################################################
    "  - A created color instance.": "  - 作成された色のインスタンス。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> color: ap.Color = ap.Color.from_rgb(red=0, green=255, blue=0)\n>>> color\nColor("#00FF00")\n```': '```py\n>>> import apysc as ap\n>>> color: ap.Color = ap.Color.from_rgb(red=0, green=255, blue=0)\n>>> color\nColor("#00FF00")\n```',  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [Color class](https://simon-ritchie.github.io/apysc/en/color.html)": "- [Color クラス](https://simon-ritchie.github.io/apysc/jp/jp_color.html)",  # noqa
}



"""The class implementation for the `add_task` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialAddTaskIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `add_task` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><rect fill="none" height="24" width="24"/><path d="M22,5.18L10.59,16.6l-4.24-4.24l1.41-1.41l2.83,2.83l10-10L22,5.18z M12,20c-4.41,0-8-3.59-8-8s3.59-8,8-8 c1.57,0,3.04,0.46,4.28,1.25l1.45-1.45C16.1,2.67,14.13,2,12,2C6.48,2,2,6.48,2,12s4.48,10,10,10c1.73,0,3.36-0.44,4.78-1.22 l-1.5-1.5C14.28,19.74,13.17,20,12,20z M19,15h-3v2h3v3h2v-3h3v-2h-3v-3h-2V15z"/></svg>'  # noqa



"""The class implementation for the `hourglass_full` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialHourglassFullIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `hourglass_full` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M6 2v6h.01L6 8.01 10 12l-4 4 .01.01H6V22h12v-5.99h-.01L18 16l-4-4 4-3.99-.01-.01H18V2H6z"/></svg>'  # noqa



"""The mix-in class implementation for the `tick_text_max_num_of_decimal_places`
value.
"""

from typing import Union

from typing_extensions import final

from apysc._html.debug_mode import add_debug_info_setting
from apysc._type.int import Int
from apysc._validation import arg_validation_decos


class TickTextMaxNumOfDecimalPlacesMixIn:
    _tick_text_max_num_of_decimal_places: Int

    @final
    @arg_validation_decos.is_integer(arg_position_index=1, optional=False)
    @add_debug_info_setting(module_name=__name__)
    def _set_initial_tick_text_max_num_of_decimal_places(
        self,
        *,
        tick_text_max_num_of_decimal_places: Union[int, Int],
        variable_name_suffix: str = "",
    ) -> None:
        """
        Set an initial tick text maximum number of decimal places.

        Parameters
        ----------
        tick_text_max_num_of_decimal_places : Union[int, Int]
            A tick text maximum number of decimal places.
        variable_name_suffix : str, optional
            A JavaScript variable name suffix string.
            This setting is sometimes useful for JavaScript debugging.
        """
        if not isinstance(tick_text_max_num_of_decimal_places, Int):
            tick_text_max_num_of_decimal_places_: Int = Int(
                tick_text_max_num_of_decimal_places,
                variable_name_suffix=variable_name_suffix,
            )
        else:
            tick_text_max_num_of_decimal_places_ = tick_text_max_num_of_decimal_places
        self._tick_text_max_num_of_decimal_places = tick_text_max_num_of_decimal_places_
